@@ -349,7 +349,6 @@ do_connect(gacopyz_conn_t conn,
 				return -1;
 			}
 		}
-#ifdef GACOPYZ_IPV6
 	} else if (strcmp(proto, "inet6") == 0) {
 		struct addrinfo hints;
 		struct addrinfo *res;
@@ -412,7 +411,6 @@ do_connect(gacopyz_conn_t conn,
 
 		memcpy(&addr, res->ai_addr, res->ai_addrlen);
 		freeaddrinfo(res);
-#endif		
 	} else {
 		if (GACOPYZ_CONN_LOG_MATCH(conn, SMI_LOG_ERR))
 			gacopyz_log(SMI_LOG_ERR,
@@ -997,8 +995,7 @@ enum state_arg_type {
 	arg_one_string,        /* one string */
 	arg_two_strings,       /* two strings */
 	arg_ints,              /* three integers */
-	arg_argv,              /* NULL-terminated, \0 separated list of
-				  arguments */
+	arg_argv,              /* list of nul-terminated strings */
 	arg_argvc              /* 1 byte command + arg_argv */
 };
 
@@ -1173,7 +1170,6 @@ shan_connect(SMFICTX *ctx, union state_arg *arg, unsigned char *cmd)
 			break;
 			
 		case SMFIA_INET6: {
-#ifdef GACOPYZ_IPV6
 			int rc;
 			struct addrinfo hints;
 			struct addrinfo *res;
@@ -1234,7 +1230,6 @@ shan_connect(SMFICTX *ctx, union state_arg *arg, unsigned char *cmd)
 			memcpy(&sockaddr, res->ai_addr, res->ai_addrlen);
                         freeaddrinfo(res);
 			break;
-#endif
 		}
 			
 		default:
@@ -1573,17 +1568,16 @@ parse_state_arg(union state_arg *arg, enum state_arg_type type,
 		return MI_SUCCESS;
 	}
 	
-	case arg_argv: /* NULL-terminated, \0 separated list of strings */
 	case arg_argvc:
+		arg->argv.cmd = *buffer;
+		buffer++;
+		size--;
+		/* arg_arg follows; fall-through */
+	case arg_argv: /* list of nul-terminated strings */
 	{
 		size_t i, count = 0;
 		char *p;
 
-		if (type == arg_argvc) {
-			arg->argv.cmd = *buffer;
-			buffer++;
-			size--;
-		}
 		arg->argv.buffer = malloc(size);
 		if (!arg->argv.buffer)
 			return MI_FAILURE;
